Blame - test/fixedbugs/issue13319.go - go - Git at Google

blob: c9b4896a05113588a358dd50535a3c349e15b6a8 [file] [log] [blame]

Robert Griesemer | 64cd867 | 2015-11-19 16:11:09 -0800 | [diff] [blame] | 1 | // errorcheck
| 2 |
Emmanuel Odeke | 53fd522 | 2016-04-10 14:32:26 -0700 | [diff] [blame] | 3 | // Copyright 2015 The Go Authors. All rights reserved.
Robert Griesemer | 64cd867 | 2015-11-19 16:11:09 -0800 | [diff] [blame] | 4 | // Use of this source code is governed by a BSD-style
| 5 | // license that can be found in the LICENSE file.
| 6 |
| 7 | package main
| 8 |
| 9 | func f(int, int) {
| 10 | switch x {
| 11 | case 1:
| 12 | f(1, g() // ERROR "expecting \)|expecting comma or \)"
| 13 | case 2:
| 14 | f()
| 15 | case 3:
| 16 | f(1, g() // ERROR "expecting \)|expecting comma or \)"
| 17 | }
| 18 | }